# UMIRobot Python

The Python package to interact with the UMIRobot.

**_NOTE:_**  The package is only compatible with Python >= 3.8.

## Installation

Use `pip` to install the package. Dependencies will be automatically installed.

`python -m pip install umirobot`

## Upgrade

`python -m pip install umirobot --upgrade`

## Usage

Run the package as a module as follows.

`python -m umirobot`

Handle the interface as needed.

